@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
-our $DATE = '2016-03-30'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-03-31'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -39,7 +39,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-30.
+This document describes version 0.04 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-31.
 
 =head1 SYNOPSIS
 
@@ -83,62 +83,6 @@ L<Perl::Examples::Accessors::Scalar> 0.03
 
 =over
 
-=item * Mo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Mo->new
-
-
-
-=item * no generator (array-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Array->new
-
-
-
-=item * no generator (scalar-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Scalar->new
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Hash->new
-
-
-
-=item * Moose (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moose->new
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassXSAccessor->new
-
-
-
-=item * Class::Accessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassAccessor->new
-
-
-
 =item * Moo (perl_code)
 
 Code template:
@@ -147,22 +91,6 @@ Code template:
 
 
 
-=item * Class::Accessor::Array (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassAccessorArray->new
-
-
-
-=item * Mouse (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Mouse->new
-
-
-
 =item * Class::XSAccessor::Array (perl_code)
 
 Code template:
@@ -171,28 +99,100 @@ Code template:
 
 
 
+=item * Mo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mo->new
+
+
+
+=item * Mouse (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mouse->new
+
+
+
+=item * no generator (scalar-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Scalar->new
+
+
+
+=item * Moose (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moose->new
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Hash->new
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Array->new
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessor->new
+
+
+
+=item * Class::Accessor::Array (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassAccessorArray->new
+
+
+
+=item * Class::Accessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassAccessor->new
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2557M CPU @ 1.70GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17 >>, OS kernel: I<< Linux version 3.13.0-32-generic >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Construction >>):
 
  +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
  | participant                 | rate (/s) | time (μs) | vs_slowest | result_size (b) | errors  | samples |
  +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
- | Moose                       | 4.2e+05   | 2.4       | 1          | 1.2e+02         | 2.5e-09 | 20      |
- | Mo                          | 5.9e+05   | 1.7       | 1.4        | 1.2e+02         | 3.3e-09 | 21      |
- | Moo                         | 8e+05     | 1.3       | 1.9        | 1.2e+02         | 1.7e-09 | 20      |
- | Class::Accessor             | 8.6e+05   | 1.2       | 2          | 1.2e+02         | 1.7e-09 | 20      |
- | Mouse                       | 1.254e+06 | 0.7971    | 2.964      | 120             | 2.3e-11 | 20      |
- | no generator (array-based)  | 1.29e+06  | 0.777     | 3.04       | 64              | 4.2e-10 | 20      |
- | no generator (hash-based)   | 1.64e+06  | 0.609     | 3.88       | 120             | 2.1e-10 | 24      |
- | Class::Accessor::Array      | 1.7e+06   | 0.58      | 4.1        | 64              | 6.1e-10 | 21      |
- | no generator (scalar-based) | 1.9e+06   | 0.54      | 4.4        | 72              | 7.5e-10 | 25      |
- | Class::XSAccessor           | 2.57e+06  | 0.389     | 6.08       | 120             | 1.7e-10 | 37      |
- | Class::XSAccessor::Array    | 2.71e+06  | 0.369     | 6.39       | 64              | 1.8e-10 | 34      |
+ | Moose                       | 4.6e+05   | 2.2       | 1          | 120             | 4.2e-09 | 20      |
+ | Mo                          | 7.35e+05  | 1.36      | 1.58       | 120             | 1.3e-09 | 20      |
+ | Moo                         | 9.22e+05  | 1.08      | 1.98       | 120             | 4e-10   | 23      |
+ | Class::Accessor             | 1.1e+06   | 0.95      | 2.3        | 120             | 1.7e-09 | 20      |
+ | Mouse                       | 1.29e+06  | 0.776     | 2.77       | 120             | 4.1e-10 | 21      |
+ | no generator (array-based)  | 1.65e+06  | 0.608     | 3.54       | 64              | 2.9e-10 | 20      |
+ | no generator (hash-based)   | 2e+06     | 0.51      | 4.2        | 120             | 9.9e-10 | 22      |
+ | no generator (scalar-based) | 2.02e+06  | 0.496     | 4.34       | 72              | 2.1e-10 | 20      |
+ | Class::Accessor::Array      | 2.08e+06  | 0.482     | 4.46       | 64              | 2.1e-10 | 20      |
+ | Class::XSAccessor::Array    | 3.2e+06   | 0.312     | 6.89       | 64              | 8.3e-11 | 20      |
+ | Class::XSAccessor           | 3.21e+06  | 0.311     | 6.91       | 120             | 9.2e-11 | 22      |
  +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
 
 =head1 DESCRIPTION
