@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::GeneratorStartup;
 
-our $DATE = '2016-03-30'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-03-31'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::GeneratorStartup - Benchmark startup of various ac
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-30.
+This document describes version 0.04 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-31.
 
 =head1 SYNOPSIS
 
@@ -69,17 +69,27 @@ L<Mouse> v2.4.5
 
 =over
 
+=item * Moo (perl_code)
+
+L<Moo>
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+L<Class::XSAccessor::Array>
+
+
+
 =item * Mo (perl_code)
 
 L<Mo>
 
 
 
-=item *  (perl_code)
+=item * Mouse (perl_code)
 
-
-
-=item *  (perl_code)
+L<Mouse>
 
 
 
@@ -93,39 +103,29 @@ L<Moose>
 
 
 
+=item *  (perl_code)
+
+
+
+=item *  (perl_code)
+
+
+
 =item * Class::XSAccessor (perl_code)
 
 L<Class::XSAccessor>
 
 
 
-=item * Class::Accessor (perl_code)
-
-L<Class::Accessor>
-
-
-
-=item * Moo (perl_code)
-
-L<Moo>
-
-
-
 =item * Class::Accessor::Array (perl_code)
 
 L<Class::Accessor::Array>
 
 
 
-=item * Mouse (perl_code)
+=item * Class::Accessor (perl_code)
 
-L<Mouse>
-
-
-
-=item * Class::XSAccessor::Array (perl_code)
-
-L<Class::XSAccessor::Array>
+L<Class::Accessor>
 
 
 
@@ -133,22 +133,22 @@ L<Class::XSAccessor::Array>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2557M CPU @ 1.70GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17 >>, OS kernel: I<< Linux version 3.13.0-32-generic >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::GeneratorStartup >>):
 
  +--------------------------+-----------+------------------------+------------+---------+---------+
  | participant              | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +--------------------------+-----------+------------------------+------------+---------+---------+
- | Moose                    | 3e+02     | 290                    | 1          | 0.0048  | 20      |
- | Mouse                    | 7e+01     | 60                     | 5          | 0.0022  | 20      |
- | Moo                      | 40        | 30                     | 7.5        | 0.00035 | 20      |
- | Class::XSAccessor::Array | 4e+01     | 30                     | 9          | 0.00061 | 20      |
- | Class::Accessor          | 3e+01     | 20                     | 1e+01      | 0.00064 | 20      |
- | Class::XSAccessor        | 26        | 16                     | 11         | 0.00017 | 25      |
- | Class::Accessor::Array   | 2e+01     | 10                     | 2e+01      | 0.00057 | 20      |
- | Mo                       | 2e+01     | 10                     | 2e+01      | 0.00065 | 21      |
- | perl -e1 (baseline)      | 1e+01     | 0                      | 2e+01      | 0.00045 | 20      |
+ | Moose                    | 1.7e+02   | 165.7                  | 1          | 0.00043 | 20      |
+ | Mouse                    | 26        | 21.7                   | 6.6        | 0.00012 | 20      |
+ | Moo                      | 20        | 15.7                   | 8.5        | 0.00012 | 20      |
+ | Class::XSAccessor::Array | 12        | 7.7                    | 14         | 8.1e-05 | 20      |
+ | Class::Accessor          | 12        | 7.7                    | 14         | 6.2e-05 | 20      |
+ | Class::XSAccessor        | 12        | 7.7                    | 15         | 5.6e-05 | 20      |
+ | Mo                       | 6.8       | 2.5                    | 25         | 5.5e-05 | 20      |
+ | Class::Accessor::Array   | 6.6       | 2.3                    | 26         | 1.8e-05 | 20      |
+ | perl -e1 (baseline)      | 4.3       | 0                      | 40         | 2.9e-05 | 20      |
  +--------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
