@@ -1,7 +1,7 @@
 package Bencher::Scenarios::Accessors;
 
-our $DATE = '2016-03-30'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-03-31'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 1;
 # ABSTRACT: Scenarios to benchmark class accessors
@@ -18,7 +18,7 @@ Bencher::Scenarios::Accessors - Scenarios to benchmark class accessors
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenarios::Accessors (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-30.
+This document describes version 0.04 of Bencher::Scenarios::Accessors (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-31.
 
 =head1 HOMEPAGE
 
@@ -36,6 +36,11 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+The L<Benchmark::Perl::Formance> distribution contains various benchmarks, in
+particular the C<Benchmark::Perl::Formance::Plugin::Accessors*> modules.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
